==> genometools-1.3.4.tar.gz: genometools-1.3.4/src/gth/bssm_param.h <==
/*
  Copyright (c) 2003-2009 Gordon Gremme <gremme@zbh.uni-hamburg.de>
  Copyright (c) 2003-2005 Michael E Sparks <mespar1@iastate.edu>
  Copyright (c) 2003-2008 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef BSSM_PARAM_H
#define BSSM_PARAM_H

#include <stdbool.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <float.h>
#include "core/error.h"
#include "core/file.h"

typedef struct GthBssmParam GthBssmParam;

typedef float  LOWPRECPROBTYPE;  /* probability type for low precision */
typedef double HIGHPRECPROBTYPE; /* probability type for high precision */

typedef enum {
  GT_DONOR_TYPE = 0,
  GC_DONOR_TYPE,
  AG_ACCEPTOR_TYPE,
  NUMOFTYPES
} Termtype;

#define UNDEFLOWPRECPROBTYPE    FLT_MAX
#define UNDEFHIGHPRECPROBTYPE   DBL_MAX

#define BSSMFILEENDING          "bssm"

GthBssmParam* gth_bssm_param_new(void);
/* Read a bssm parameter file on the path $BSSMDIR. */
GthBssmParam* gth_bssm_param_load(const char *filename, GtError*);
GthBssmParam* gth_bssm_param_extract(unsigned long speciesnum, GtError*);
void          gth_bssm_param_delete(GthBssmParam*);
/* Save the data contained in <bssm_param> to a file named <filename>. */
int           gth_bssm_param_save(GthBssmParam*, const char *filename,
                                  GtError*);
/* Prints the contents of the bssm parameterization <bssm_param> to <outfp>. */
void          gth_bssm_param_echo(const GthBssmParam *bssm_param, FILE *outfp);
void          gth_bssm_param_show_info(const GthBssmParam*, GtFile *outfp);
int           gth_bssm_param_parameterize(GthBssmParam*, const char *path,
                                          Termtype, bool gzip, GtError*);

#endif

==> genometools-1.3.5.tar.gz: genometools-1.3.5/src/gth/bssm_param.h <==
/*
  Copyright (c) 2003-2009 Gordon Gremme <gremme@zbh.uni-hamburg.de>
  Copyright (c) 2003-2005 Michael E Sparks <mespar1@iastate.edu>
  Copyright (c) 2003-2008 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef BSSM_PARAM_H
#define BSSM_PARAM_H

#include <stdbool.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <float.h>
#include "core/error.h"
#include "core/file.h"

typedef struct GthBssmParam GthBssmParam;

typedef float  GthFlt;  /* probability type for low precision */
typedef double GthDbl; /* probability type for high precision */

typedef enum {
  GT_DONOR_TYPE = 0,
  GC_DONOR_TYPE,
  AG_ACCEPTOR_TYPE,
  NUMOFTYPES
} Termtype;

#define UNDEF_GTHFLT    FLT_MAX
#define UNDEF_GTHDBL   DBL_MAX

#define BSSMFILEENDING          "bssm"

GthBssmParam* gth_bssm_param_new(void);
/* Read a bssm parameter file on the path $BSSMDIR. */
GthBssmParam* gth_bssm_param_load(const char *filename, GtError*);
GthBssmParam* gth_bssm_param_extract(unsigned long speciesnum, GtError*);
void          gth_bssm_param_delete(GthBssmParam*);
/* Save the data contained in <bssm_param> to a file named <filename>. */
int           gth_bssm_param_save(GthBssmParam*, const char *filename,
                                  GtError*);
/* Prints the contents of the bssm parameterization <bssm_param> to <outfp>. */
void          gth_bssm_param_echo(const GthBssmParam *bssm_param, FILE *outfp);
void          gth_bssm_param_show_info(const GthBssmParam*, GtFile *outfp);
int           gth_bssm_param_parameterize(GthBssmParam*, const char *path,
                                          Termtype, bool gzip, GtError*);

#endif
